package xn.hxp.ui.plan.already;

import android.content.Context;
import android.content.Intent;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;

import androidx.activity.result.ActivityResultLauncher;

import com.blankj.utilcode.util.LogUtils;
import com.kongzue.dialogx.dialogs.PopTip;
import com.rc.httpcore.bean.HxpChemicalVo;

import java.util.ArrayList;
import java.util.List;

import xn.hxp.databinding.ItemAlreadyBinding;
import xn.hxp.ui.PrintBean;
import xn.hxp.ui.plan.change.ChangeCabinetActivity;
import xn.hxp.utils.PrintTool;

public class AlreadyAdapter extends BaseAdapter {
    private Context context;
    private List<HxpChemicalVo> recordsBeanList;

    // 存储位置替换的回调
    private ActivityResultLauncher<Intent> intentActivityResultLauncher;

    public AlreadyAdapter(Context context, List<HxpChemicalVo> recordsBeanList, ActivityResultLauncher<Intent> intentActivityResultLauncher) {
        this.context = context;
        this.recordsBeanList = recordsBeanList;
        this.intentActivityResultLauncher = intentActivityResultLauncher;
    }

    @Override
    public int getCount() {
        return recordsBeanList.size();
    }

    @Override
    public HxpChemicalVo getItem(int position) {
        return recordsBeanList.get(position);
    }

    @Override
    public long getItemId(int position) {
        return 0;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder viewHolder;
        if (convertView == null) {
            ItemAlreadyBinding binding = ItemAlreadyBinding.inflate(LayoutInflater.from(context), parent, false);
            convertView = binding.getRoot();
            viewHolder = new ViewHolder(binding);
            convertView.setTag(viewHolder);
        } else {
            viewHolder = (ViewHolder) convertView.getTag();
        }

        try {
            HxpChemicalVo recordsBean = getItem(position);
            ItemAlreadyBinding binding = viewHolder.binding;
            // 申领单号
            String applyOrder = recordsBean.getApplyOrder();
            binding.alreadyCodeTV.setText(TextUtils.isEmpty(applyOrder) ? "" : applyOrder);
            // 化学品名称
            String chemicalName = recordsBean.getChemicalName();
            binding.name.setText(TextUtils.isEmpty(chemicalName) ? "" : chemicalName);
            // 类别
            String chemicalCategoryName = recordsBean.getChemicalCategoryName();
            binding.type.setText(TextUtils.isEmpty(chemicalCategoryName) ? "" : chemicalCategoryName);
            // CAS
            String casNum = recordsBean.getCasNum();
            binding.cas.setText(TextUtils.isEmpty(casNum) ? "" : casNum);
            // 纯度
            String chemicalPurity = recordsBean.getChemicalPurity();
            binding.purity.setText(TextUtils.isEmpty(chemicalPurity) ? "" : chemicalPurity);
            // 规格
            String normsNum = recordsBean.getNormsNum();
            String normsUnit = recordsBean.getNormsUnit();
            binding.specs.setText(normsNum + (TextUtils.isEmpty(normsUnit) ? "" : normsUnit));
            // 申领人
            String applyUserName = recordsBean.getApplyUserName();
            binding.applicantTV.setText(TextUtils.isEmpty(applyUserName) ? "" : applyUserName);
            // 归属人
            boolean topicGroup = recordsBean.isTopicGroup();
            // 是否是课题组
            if (topicGroup) {
                String topicGroupName = recordsBean.getTopicGroupName();
                binding.belongTV.setText(TextUtils.isEmpty(topicGroupName) ? "" : topicGroupName);
            } else {
                binding.belongTV.setText(TextUtils.isEmpty(applyUserName) ? "" : applyUserName);
            }
            // 编码
            String labels = recordsBean.getLabels();
            binding.code.setText(TextUtils.isEmpty(labels) ? "" : labels);
            // 存储位置
            String cabinetName = recordsBean.getCabinetName();
            String doorName = recordsBean.getDoorName();
            int doorLayers = recordsBean.getDoorLayers();
            binding.save.setText(cabinetName + "-" + doorName + "-" + doorLayers + "层");
            // 是否被选择
            binding.selectCB.setChecked(recordsBean.isSelect());
            binding.selectCB.setOnCheckedChangeListener(null);
            binding.selectCB.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (binding.selectCB.isChecked()) {
                        PopTip.show("选择" + position);
                    } else {
                        PopTip.show("反选" + position);
                    }
                    HxpChemicalVo recordsBean = getItem(position);
                    recordsBean.setSelect(binding.selectCB.isChecked());
                }
            });
            binding.save.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    recordsBeanList.get(position).setSelect(true);
                    notifyDataSetChanged();
                    List<String> waitArray = new ArrayList<>();
                    for (int i = 0; i < recordsBeanList.size(); i++) {
                        HxpChemicalVo recordsBean = recordsBeanList.get(i);
                        if (recordsBean.isSelect()) {
                            waitArray.add(recordsBean.getWaitId());
                        }
                    }
                    LogUtils.json(waitArray);

                    intentActivityResultLauncher.launch(new Intent(context, ChangeCabinetActivity.class));
                    PopTip.show("存储" + position + " ," + waitArray.size() + "个");

                }
            });

            binding.operate.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    try {
                        HxpChemicalVo printAlreadyBean = recordsBeanList.get(position);
                        printAlreadyBean.setSelect(true);
                        notifyDataSetChanged();
                        List<HxpChemicalVo> rrintBeanList = new ArrayList<>();
                        for (int i = 0; i < recordsBeanList.size(); i++) {
                            HxpChemicalVo recordsBean = recordsBeanList.get(i);
                            if (recordsBean.isSelect()) {
                                rrintBeanList.add(recordsBean);
                            }
                        }
                        LogUtils.json(rrintBeanList);
                        PopTip.show("打印" + position + " ," + rrintBeanList.size() + "个");
                        for (int i = 0; i < rrintBeanList.size(); i++) {
                            PrintBean printBean = new PrintBean();
                            // 化学品编码
                            HxpChemicalVo itemBean = rrintBeanList.get(i);
                            String tagCode = itemBean.getLabels();
                            printBean.setTag(TextUtils.isEmpty(tagCode) ? "" : tagCode);
                            // 二维码
                            printBean.setWxCode(TextUtils.isEmpty(tagCode) ? "" : tagCode);
                            // 化学品名
                            printBean.setName(TextUtils.isEmpty(chemicalName) ? "" : chemicalName);
                            // CAS
                            String casNum = itemBean.getCasNum();
                            printBean.setCasNo(TextUtils.isEmpty(casNum) ? "" : casNum);
                            int belongType = itemBean.getBelongType();
                            String name = "";
                            // 是否是课题组
                            if (itemBean.isTopicGroup()) {
                                name = itemBean.getTopicGroupName();
                            } else {
                                name = itemBean.getApplyUserName();
                            }
                            printBean.setPerson(TextUtils.isEmpty(name) ? "" : name);
                            // 化学品类型
                            CharSequence chemicalCategory = itemBean.getChemicalCategoryName();
                            printBean.setTypes(TextUtils.isEmpty(chemicalCategory) ? "" : chemicalCategory.toString());
                            PrintTool.INSTANCE.print(true, !itemBean.isTopicGroup(), printBean);
                        }

                    } catch (Exception e) {
                        LogUtils.e(Log.getStackTraceString(e));
                    }
                }
            });
        } catch (Exception e) {
            LogUtils.e(Log.getStackTraceString(e));
        }

        return convertView;
    }

    static class ViewHolder {
        ItemAlreadyBinding binding;

        public ViewHolder(ItemAlreadyBinding binding) {
            this.binding = binding;
        }
    }
}
